==> core_models-0.1.0.gem: app/controllers/core_models/base/colours_controller.rb <==
require_dependency "core_models/core_models_controller"

module CoreModels
  class Base::ColoursController < CoreModelsController
    # GET /base/colours
    # GET /base/colours.json
    def index
      @base_colours = Base::Colour.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @base_colours }
      end
    end

    # GET /base/colours/1
    # GET /base/colours/1.json
    def show
      @base_colour = Base::Colour.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @base_colour }
      end
    end

    # GET /base/colours/new
    # GET /base/colours/new.json
    def new
      @base_colour = Base::Colour.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @base_colour }
      end
    end

    # GET /base/colours/1/edit
    def edit
      @base_colour = Base::Colour.find(params[:id])
    end

    # POST /base/colours
    # POST /base/colours.json
    def create
      @base_colour = Base::Colour.new(params[:base_colour])

      respond_to do |format|
        if @base_colour.save
          format.html { redirect_to @base_colour, :notice => 'Colour was successfully created.' }
          format.json { render :json => @base_colour, :status => :created, :location => @base_colour }
        else
          format.html { render :action => "new" }
          format.json { render :json => @base_colour.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /base/colours/1
    # PUT /base/colours/1.json
    def update
      @base_colour = Base::Colour.find(params[:id])

      respond_to do |format|
        if @base_colour.update_attributes(params[:base_colour])
          format.html { redirect_to @base_colour, :notice => 'Colour was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @base_colour.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /base/colours/1
    # DELETE /base/colours/1.json
    def destroy
      @base_colour = Base::Colour.find(params[:id])
      @base_colour.destroy

      respond_to do |format|
        format.html { redirect_to base_colours_url }
        format.json { head :no_content }
      end
    end
  end
end

==> core_models-0.2.9.gem: app/controllers/core_models/base/colours_controller.rb <==
require_dependency "core_models/core_models_controller"

module CoreModels
  class Base::ColoursController < CoreModelsController
    # GET /base/colours
    # GET /base/colours.json
    def index
      @base_colours = Base::Colour.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @base_colours }
      end
    end

    # GET /base/colours/1
    # GET /base/colours/1.json
    def show
      @base_colour = Base::Colour.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @base_colour }
      end
    end

    # GET /base/colours/new
    # GET /base/colours/new.json
    def new
      @base_colour = Base::Colour.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @base_colour }
      end
    end

    # GET /base/colours/1/edit
    def edit
      @base_colour = Base::Colour.find(params[:id])
    end

    # POST /base/colours
    # POST /base/colours.json
    def create
      @base_colour = Base::Colour.new(params[:base_colour])

      respond_to do |format|
        if @base_colour.save
          format.html { redirect_to @base_colour, :notice => 'Colour was successfully created.' }
          format.json { render :json => @base_colour, :status => :created, :location => @base_colour }
        else
          format.html { render :action => "new" }
          format.json { render :json => @base_colour.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /base/colours/1
    # PUT /base/colours/1.json
    def update
      @base_colour = Base::Colour.find(params[:id])

      respond_to do |format|
        if @base_colour.update(params[:base_colour])
          format.html { redirect_to @base_colour, :notice => 'Colour was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @base_colour.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /base/colours/1
    # DELETE /base/colours/1.json
    def destroy
      @base_colour = Base::Colour.find(params[:id])
      @base_colour.destroy

      respond_to do |format|
        format.html { redirect_to base_colours_url }
        format.json { head :no_content }
      end
    end
  end
end
